==> prestashop_1.5.0.9.zip: prestashop/modules/followup/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{followup}prestashop>followup_9c34e90380dac7b56fdd19192a99d531'] = 'Relance des clients';
$_MODULE['<{followup}prestashop>followup_57476355fcd04050bff196ae9aa4673c'] = 'Relancez vos clients grâce à des envoi d\'e-mails quotidiens personnalisés.';
$_MODULE['<{followup}prestashop>followup_f71a41841c80c2ef0ec02a6ad5449c65'] = 'Êtes-vous sûr de vouloir supprimer vos paramètres ainsi que vos statistiques liées aux relances ?';
$_MODULE['<{followup}prestashop>followup_f4f70727dc34561dfde1a3c529b6205c'] = 'Paramètres';
$_MODULE['<{followup}prestashop>followup_599fac49ffe947cd0f9e934e6af89879'] = 'Quatre types de relances afin de rester en contact avec vos clients !';
$_MODULE['<{followup}prestashop>followup_8b1aa589b33a54906ae78f5820eab42c'] = 'Effectuez vos réglages et ajoutez cette URL à votre crontab, ou visitez-la manuellement chaque jour :';
$_MODULE['<{followup}prestashop>followup_b547c073d144a57761d1d00d0b9d9f27'] = 'Paniers annulés';
$_MODULE['<{followup}prestashop>followup_ea9dc62a0ddf4640f019f04a22ab9835'] = 'Pour chaque panier abandonné (sans commande), génère un bon d\'achat et l\'envoie au client';
$_MODULE['<{followup}prestashop>followup_2faec1f9f8cc7f8f40d521c4dd574f49'] = 'Activé';
$_MODULE['<{followup}prestashop>followup_b30690be173bcd4a83df0cd68f89a385'] = 'Montant de la remise';
$_MODULE['<{followup}prestashop>followup_2018945d252b94aeb99b0909f288717c'] = 'Durée de validité';
$_MODULE['<{followup}prestashop>followup_225e75c29d32392d311f5dc94c792384'] = 'jour(s)';
$_MODULE['<{followup}prestashop>followup_79645190f574ce5b72b89f4122107b72'] = 'Le prochain envoi transmettra :';
$_MODULE['<{followup}prestashop>followup_46e89640babbc6a0e52599a92a6c13b4'] = 'e-mails';
$_MODULE['<{followup}prestashop>followup_1ec5f5ec77c51a968271b2ca9862907d'] = 'e-mail';
$_MODULE['<{followup}prestashop>followup_a8b8dbd070a92fb8b17baab71d8d633f'] = 'Re-commander';
$_MODULE['<{followup}prestashop>followup_895858cf10b8a1750a42875cb9c69092'] = 'Pour chaque commande validée, génère un bon d\'achat et l\'envoie au client';
$_MODULE['<{followup}prestashop>followup_8b83489bd116cb60e2f348e9c63cd7f6'] = 'Meilleurs clients';
$_MODULE['<{followup}prestashop>followup_a46ad892f7f00e051cc90050ff2e1ddf'] = 'Pour chaque client dont le total des commandes atteint un certain seuil, génère un bon d\'achat et l\'envoie au client';
$_MODULE['<{followup}prestashop>followup_2a63f555989152ba866b43a1faacd680'] = 'Seuil';
$_MODULE['<{followup}prestashop>followup_7d75b7b0f976b3091f490864c6ffbf97'] = 'Mauvais clients';
$_MODULE['<{followup}prestashop>followup_e552313de5ebebdafa8bfa0dcc703e19'] = 'Pour chaque client ayant déjà passé commande au moins une fois et sans commande depuis une certaine durée, génère un bon d\'achat et l\'envoie au client';
$_MODULE['<{followup}prestashop>followup_d82843c16839bfb05827d1912d89c917'] = 'Depuis x jours';
$_MODULE['<{followup}prestashop>followup_3fb7b0bbf0c95bba3ed2ba0b147ca588'] = 'Supprimer les bons d\'achat dont la date d\'expiration est dépassée afin de nettoyer la base de données.';
$_MODULE['<{followup}prestashop>followup_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{followup}prestashop>followup_c33e404a441c6ba9648f88af3c68a1ca'] = 'Statistiques';
$_MODULE['<{followup}prestashop>followup_1deaabda093f617a57f732c07e635fac'] = 'Statistiques détaillées sur les 30 derniers jours :';
$_MODULE['<{followup}prestashop>followup_f23b0eec6c25c49afa4b29c57e671728'] = 'E = Nombre d\'e-mails envoyés';
$_MODULE['<{followup}prestashop>followup_fde0b9a66bffdd6ee0886613e8031d9a'] = 'U = Nombre de bons d\'achat utilisés (commandes valides uniquement)';
$_MODULE['<{followup}prestashop>followup_cceb59e78d00c10436ff5e777dd5d895'] = '% = Taux de transformation';
$_MODULE['<{followup}prestashop>followup_44749712dbec183e983dcd78a7736c41'] = 'Date';
$_MODULE['<{followup}prestashop>followup_5e53dfa887dfb989f0bc3e9fb9b34a2d'] = 'Meilleurs clients';
$_MODULE['<{followup}prestashop>followup_66ff4e89c767ab0a4e5ddc0251a101bc'] = 'Mauvais clients';
$_MODULE['<{followup}prestashop>followup_5dbc98dcc983a70728bd082d1a47546e'] = 'E';
$_MODULE['<{followup}prestashop>followup_4c614360da93c0a041b22e537de151eb'] = 'U';
$_MODULE['<{followup}prestashop>followup_85b6769250887ba6c16099596c75164d'] = 'Aucune donnée enregistrée pour l\'instant.';
$_MODULE['<{followup}prestashop>followup_edf9feeab43a7623f6afc152d1ede515'] = 'Bon de réduction pour votre panier abandonné';
$_MODULE['<{followup}prestashop>followup_a053fc9952a7dfc79282eba56ab8ad3a'] = 'Merci pour votre commande.';
$_MODULE['<{followup}prestashop>followup_7fcd592dd47028c7c1f2d0ce9168a303'] = 'Vous êtes l\'un de nos meilleurs clients !';
$_MODULE['<{followup}prestashop>followup_c2ab23672d4bb31c7664bf8e854a10f7'] = 'Vous nous manquez !';

==> prestashop_1.5.1.0.zip: prestashop/modules/followup/translations/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{followup}prestashop>followup_9c34e90380dac7b56fdd19192a99d531'] = 'Relance des clients';
$_MODULE['<{followup}prestashop>followup_57476355fcd04050bff196ae9aa4673c'] = 'Relancez vos clients grâce à des envoi d\'e-mails quotidiens personnalisés.';
$_MODULE['<{followup}prestashop>followup_f71a41841c80c2ef0ec02a6ad5449c65'] = 'Êtes-vous sûr de vouloir supprimer vos paramètres ainsi que vos statistiques liées aux relances ?';
$_MODULE['<{followup}prestashop>followup_f4f70727dc34561dfde1a3c529b6205c'] = 'Paramètres';
$_MODULE['<{followup}prestashop>followup_599fac49ffe947cd0f9e934e6af89879'] = 'Quatre types de relances afin de rester en contact avec vos clients !';
$_MODULE['<{followup}prestashop>followup_8b1aa589b33a54906ae78f5820eab42c'] = 'Effectuez vos réglages et ajoutez cette URL à votre crontab, ou visitez-la manuellement chaque jour :';
$_MODULE['<{followup}prestashop>followup_b547c073d144a57761d1d00d0b9d9f27'] = 'Paniers annulés';
$_MODULE['<{followup}prestashop>followup_ea9dc62a0ddf4640f019f04a22ab9835'] = 'Pour chaque panier abandonné (sans commande), génère un bon d\'achat et l\'envoie au client';
$_MODULE['<{followup}prestashop>followup_2faec1f9f8cc7f8f40d521c4dd574f49'] = 'Activé';
$_MODULE['<{followup}prestashop>followup_b30690be173bcd4a83df0cd68f89a385'] = 'Montant de la remise';
$_MODULE['<{followup}prestashop>followup_2018945d252b94aeb99b0909f288717c'] = 'Durée de validité';
$_MODULE['<{followup}prestashop>followup_225e75c29d32392d311f5dc94c792384'] = 'jour(s)';
$_MODULE['<{followup}prestashop>followup_dcc0220e44b6d9be3d709d5c2cd34917'] = 'Le prochain envoi transmettra : %d e-mails';
$_MODULE['<{followup}prestashop>followup_3ae92a92fa710dca82e5b6667da30b7b'] = 'Le prochain envoi transmettra : %d e-mail';
$_MODULE['<{followup}prestashop>followup_a8b8dbd070a92fb8b17baab71d8d633f'] = 'Re-commander';
$_MODULE['<{followup}prestashop>followup_895858cf10b8a1750a42875cb9c69092'] = 'Pour chaque commande validée, génère un bon d\'achat et l\'envoie au client';
$_MODULE['<{followup}prestashop>followup_8b83489bd116cb60e2f348e9c63cd7f6'] = 'Meilleurs clients';
$_MODULE['<{followup}prestashop>followup_a46ad892f7f00e051cc90050ff2e1ddf'] = 'Pour chaque client dont le total des commandes atteint un certain seuil, génère un bon d\'achat et l\'envoie au client';
$_MODULE['<{followup}prestashop>followup_2a63f555989152ba866b43a1faacd680'] = 'Seuil';
$_MODULE['<{followup}prestashop>followup_7d75b7b0f976b3091f490864c6ffbf97'] = 'Mauvais clients';
$_MODULE['<{followup}prestashop>followup_e552313de5ebebdafa8bfa0dcc703e19'] = 'Pour chaque client ayant déjà passé commande au moins une fois et sans commande depuis une certaine durée, génère un bon d\'achat et l\'envoie au client';
$_MODULE['<{followup}prestashop>followup_d82843c16839bfb05827d1912d89c917'] = 'Depuis x jours';
$_MODULE['<{followup}prestashop>followup_3fb7b0bbf0c95bba3ed2ba0b147ca588'] = 'Supprimer les bons d\'achat dont la date d\'expiration est dépassée afin de nettoyer la base de données.';
$_MODULE['<{followup}prestashop>followup_c9cc8cce247e49bae79f15173ce97354'] = 'Enregistrer';
$_MODULE['<{followup}prestashop>followup_c33e404a441c6ba9648f88af3c68a1ca'] = 'Statistiques';
$_MODULE['<{followup}prestashop>followup_1deaabda093f617a57f732c07e635fac'] = 'Statistiques détaillées sur les 30 derniers jours :';
$_MODULE['<{followup}prestashop>followup_f23b0eec6c25c49afa4b29c57e671728'] = 'E = Nombre d\'e-mails envoyés';
$_MODULE['<{followup}prestashop>followup_fde0b9a66bffdd6ee0886613e8031d9a'] = 'U = Nombre de bons d\'achat utilisés (commandes valides uniquement)';
$_MODULE['<{followup}prestashop>followup_cceb59e78d00c10436ff5e777dd5d895'] = '% = Taux de transformation';
$_MODULE['<{followup}prestashop>followup_44749712dbec183e983dcd78a7736c41'] = 'Date';
$_MODULE['<{followup}prestashop>followup_5e53dfa887dfb989f0bc3e9fb9b34a2d'] = 'Meilleurs clients';
$_MODULE['<{followup}prestashop>followup_66ff4e89c767ab0a4e5ddc0251a101bc'] = 'Mauvais clients';
$_MODULE['<{followup}prestashop>followup_5dbc98dcc983a70728bd082d1a47546e'] = 'E';
$_MODULE['<{followup}prestashop>followup_4c614360da93c0a041b22e537de151eb'] = 'U';
$_MODULE['<{followup}prestashop>followup_85b6769250887ba6c16099596c75164d'] = 'Aucune donnée enregistrée pour l\'instant.';
$_MODULE['<{followup}prestashop>followup_edf9feeab43a7623f6afc152d1ede515'] = 'Bon de réduction pour votre panier abandonné';
$_MODULE['<{followup}prestashop>followup_a053fc9952a7dfc79282eba56ab8ad3a'] = 'Merci pour votre commande.';
$_MODULE['<{followup}prestashop>followup_7fcd592dd47028c7c1f2d0ce9168a303'] = 'Vous êtes l\'un de nos meilleurs clients !';
$_MODULE['<{followup}prestashop>followup_c2ab23672d4bb31c7664bf8e854a10f7'] = 'Vous nous manquez !';
